This folder contains an example config to map into a generic IOC at
runtime.

The system test 'tests/sys-test.sh' uses this to launch the generic
ioc 'ioc-template' and verify that it serves the correct PVs.
